FiftyAudioLogger class

Audio Logger

Utility class for logging audio-related actions and transitions (for debugging and development purposes only).

Can be toggled on/off globally using AudioLogger.enabled.

─────────────────────────────────────────────────────────────────────────────

Constructors

FiftyAudioLogger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

enabled bool
getter/setter pair

Static Methods

activate() → void
deactivate() → void
fade(double from, double to, Duration duration, Curve curve) → void
log(String message) → void
mute() → void
pause() → void
play(String pathOrType) → void
resume() → void
stop() → void
unmute() → void
volume(double value) → void