play method
Play by Path
Resolves path via the current builder and delegates to playFromSource.
Implementation
Future<void> play(String path) async {
final src = _sourceBuilder(path);
await playFromSource(src);
}
Play by Path
Resolves path via the current builder and delegates to playFromSource.
Future<void> play(String path) async {
final src = _sourceBuilder(path);
await playFromSource(src);
}