resolveSource method
Resolve a path into a Source using the current builder (assets/files/urls). Override via changeSource to switch the strategy at runtime.
Implementation
@protected
Source resolveSource(String path) => _sourceBuilder(path);
Resolve a path into a Source using the current builder (assets/files/urls). Override via changeSource to switch the strategy at runtime.
@protected
Source resolveSource(String path) => _sourceBuilder(path);