unmute method

Future<void> unmute()
inherited

Unmute (volume → 1.0)

If you want to restore to a remembered value, call setVolume with that value instead of using this convenience method.

Implementation

Future<void> unmute() async {
  FiftyAudioLogger.unmute();
  await setVolume(1.0);
}