bgm property

BgmChannel bgm
latefinal

Background Music Manager

Long-form tracks (MP3/AAC/OGG). Uses PlayerMode.mediaPlayer under the hood, loops by default, and is designed to keep playing while other channels emit sounds.

Implementation

late final BgmChannel bgm;