BgmStorage class abstract
Storage Interface for BGM Playlist
Abstracts where the BGM playlist and index are stored — could be memory, shared preferences, file, etc.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void -
getIndex(
) → int? -
getPlaylist(
) → List< String> ? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
List< String> playlist, int index) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited