VolumeStorage class abstract

Volume Storage Interface

Abstracts persistent volume state for each audio group. Used by audio managers to load/save user volume preferences.

─────────────────────────────────────────────────────────────────────────────

Implementers

Constructors

VolumeStorage()

Properties

bgmVolume double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sfxVolume double
getter/setter pair
voiceVolume double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited