FiftyAudioLogger class
Audio Logger
Utility class for logging audio-related actions and transitions (for debugging and development purposes only).
Can be toggled on/off globally using AudioLogger.enabled.
─────────────────────────────────────────────────────────────────────────────
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited