ChannelLifecycleConfig class
Lifecycle configuration per channel.
Constructors
- ChannelLifecycleConfig({ChannelBackgroundAction onBackground = ChannelBackgroundAction.pause, bool resumeOnForeground = true, bool unmuteOnForeground = true, bool fadeOnBackground = true, bool fadeOnForeground = true, FadePreset fadeOutPreset = FadePreset.fast, FadePreset fadeInPreset = FadePreset.normal, bool stopOnDetached = false})
-
const
Properties
- fadeInPreset → FadePreset
-
final
- fadeOnBackground → bool
-
Fade on background (applies before pause/mute/stop).
final
- fadeOnForeground → bool
-
Fade on foreground (applies after resume/unmute).
final
- fadeOutPreset → FadePreset
-
Fade presets.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onBackground → ChannelBackgroundAction
-
What to do when the app is backgrounded (paused/inactive/hidden).
final
- resumeOnForeground → bool
-
Whether to resume on foreground if we paused.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stopOnDetached → bool
-
Stop on detached (app is being destroyed).
final
- unmuteOnForeground → bool
-
Whether to unmute on foreground if we muted.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited