ActivationStorage class abstract
Activation Storage Interface
Abstracts the persistent "active" state for each audio channel (BGM, SFX, Voice).
Implemented by storage services like AudioMemoryService.
This allows you to store whether each sound type is enabled or disabled.
─────────────────────────────────────────────────────────────────────────────
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBgmActive ↔ bool
-
getter/setter pair
- isSfxActive ↔ bool
-
getter/setter pair
- isVoiceActive ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited